Three output tables containing the level of replication (number of replicates) and the experimental uncoded
values of the quantitative factors to be used for experimentation and one plot showing
the corresponding variance of the predicted response.
“Factorial.Points”, the first table which contains the treatment combinations for a 2^k factorial design
(which, in coded form, corresponds to the vertices of a square, a cube, or a hyper-cube when k = 2, 3 and
more).
“Axial.Points”, the second table which contains 2k axial or “star” points.
“Central.Point”, the third table which contains the number of replicates for the central point, coded (0, 0, 0).